////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  linearization_3_3_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "linearization_3_3_0.h"
#include "parametersetmanager.h"

LINEARIZATION_3_3_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "r_lut_p_tab") == 0)
    {
        __result = r_lut_p_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "r_lut_base_tab") == 0)
    {
        __result = r_lut_base_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gr_lut_p_tab") == 0)
    {
        __result = gr_lut_p_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gr_lut_base_tab") == 0)
    {
        __result = gr_lut_base_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gb_lut_p_tab") == 0)
    {
        __result = gb_lut_p_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gb_lut_base_tab") == 0)
    {
        __result = gb_lut_base_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "b_lut_p_tab") == 0)
    {
        __result = b_lut_p_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "b_lut_base_tab") == 0)
    {
        __result = b_lut_base_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool linearization33_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "r_lut_p_tab") == 0)
    {
        __result = r_lut_p_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "r_lut_base_tab") == 0)
    {
        __result = r_lut_base_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gr_lut_p_tab") == 0)
    {
        __result = gr_lut_p_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gr_lut_base_tab") == 0)
    {
        __result = gr_lut_base_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gb_lut_p_tab") == 0)
    {
        __result = gb_lut_p_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gb_lut_base_tab") == 0)
    {
        __result = gb_lut_base_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "b_lut_p_tab") == 0)
    {
        __result = b_lut_p_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "b_lut_base_tab") == 0)
    {
        __result = b_lut_base_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool linearization33_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // r_lut_p_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("r_lut_p_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "r_lut_p_tab") == 0)
    {
        __result = r_lut_p_tab.GetInfo(&__path[__pos], __info);
    }

    // r_lut_base_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("r_lut_base_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "r_lut_base_tab") == 0)
    {
        __result = r_lut_base_tab.GetInfo(&__path[__pos], __info);
    }

    // gr_lut_p_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gr_lut_p_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gr_lut_p_tab") == 0)
    {
        __result = gr_lut_p_tab.GetInfo(&__path[__pos], __info);
    }

    // gr_lut_base_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gr_lut_base_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gr_lut_base_tab") == 0)
    {
        __result = gr_lut_base_tab.GetInfo(&__path[__pos], __info);
    }

    // gb_lut_p_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gb_lut_p_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gb_lut_p_tab") == 0)
    {
        __result = gb_lut_p_tab.GetInfo(&__path[__pos], __info);
    }

    // gb_lut_base_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gb_lut_base_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gb_lut_base_tab") == 0)
    {
        __result = gb_lut_base_tab.GetInfo(&__path[__pos], __info);
    }

    // b_lut_p_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("b_lut_p_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "b_lut_p_tab") == 0)
    {
        __result = b_lut_p_tab.GetInfo(&__path[__pos], __info);
    }

    // b_lut_base_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("b_lut_base_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "b_lut_base_tab") == 0)
    {
        __result = b_lut_base_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool linearization33_rgn_dataType::r_lut_p_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "r_lut_p") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)r_lut_p[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)r_lut_p[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::r_lut_p_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "r_lut_p") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                r_lut_p[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    r_lut_p[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::r_lut_p_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // r_lut_p
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("r_lut_p", ParameterParserDataType::UInt32, true, false, 8));
    }

    return __result;
}

bool linearization33_rgn_dataType::r_lut_base_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "r_lut_base") == 0)
    {
        if (__index < 9)
        {
            ParameterUtils::DoubleToString((double)r_lut_base[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 9; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)r_lut_base[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::r_lut_base_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "r_lut_base") == 0)
    {
        if (__index < 9)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                r_lut_base[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 9)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    r_lut_base[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::r_lut_base_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // r_lut_base
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("r_lut_base", ParameterParserDataType::UInt32, true, false, 9));
    }

    return __result;
}

bool linearization33_rgn_dataType::gr_lut_p_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gr_lut_p") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)gr_lut_p[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)gr_lut_p[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gr_lut_p_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gr_lut_p") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                gr_lut_p[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    gr_lut_p[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gr_lut_p_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gr_lut_p
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gr_lut_p", ParameterParserDataType::UInt32, true, false, 8));
    }

    return __result;
}

bool linearization33_rgn_dataType::gr_lut_base_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gr_lut_base") == 0)
    {
        if (__index < 9)
        {
            ParameterUtils::DoubleToString((double)gr_lut_base[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 9; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)gr_lut_base[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gr_lut_base_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gr_lut_base") == 0)
    {
        if (__index < 9)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                gr_lut_base[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 9)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    gr_lut_base[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gr_lut_base_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gr_lut_base
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gr_lut_base", ParameterParserDataType::UInt32, true, false, 9));
    }

    return __result;
}

bool linearization33_rgn_dataType::gb_lut_p_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gb_lut_p") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)gb_lut_p[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)gb_lut_p[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gb_lut_p_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gb_lut_p") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                gb_lut_p[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    gb_lut_p[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gb_lut_p_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gb_lut_p
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gb_lut_p", ParameterParserDataType::UInt32, true, false, 8));
    }

    return __result;
}

bool linearization33_rgn_dataType::gb_lut_base_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gb_lut_base") == 0)
    {
        if (__index < 9)
        {
            ParameterUtils::DoubleToString((double)gb_lut_base[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 9; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)gb_lut_base[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gb_lut_base_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gb_lut_base") == 0)
    {
        if (__index < 9)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                gb_lut_base[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 9)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    gb_lut_base[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::gb_lut_base_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gb_lut_base
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gb_lut_base", ParameterParserDataType::UInt32, true, false, 9));
    }

    return __result;
}

bool linearization33_rgn_dataType::b_lut_p_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "b_lut_p") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)b_lut_p[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)b_lut_p[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::b_lut_p_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "b_lut_p") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                b_lut_p[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    b_lut_p[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::b_lut_p_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // b_lut_p
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("b_lut_p", ParameterParserDataType::UInt32, true, false, 8));
    }

    return __result;
}

bool linearization33_rgn_dataType::b_lut_base_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "b_lut_base") == 0)
    {
        if (__index < 9)
        {
            ParameterUtils::DoubleToString((double)b_lut_base[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 9; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)b_lut_base[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::b_lut_base_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "b_lut_base") == 0)
    {
        if (__index < 9)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                b_lut_base[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 9)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    b_lut_base[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool linearization33_rgn_dataType::b_lut_base_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // b_lut_base
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("b_lut_base", ParameterParserDataType::UInt32, true, false, 9));
    }

    return __result;
}

bool mod_linearization33_cct_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "linearization33_rgn_data") == 0)
    {
        __result = linearization33_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_linearization33_cct_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "linearization33_rgn_data") == 0)
    {
        __result = linearization33_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_linearization33_cct_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // cct_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("cct_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "cct_trigger") == 0)
    {
        __result = cct_trigger.GetInfo(&__path[__pos], __info);
    }

    // linearization33_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("linearization33_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "linearization33_rgn_data") == 0)
    {
        __result = linearization33_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_linearization33_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_linearization33_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_linearization33_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_data") == 0)
    {
        __result = aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_linearization33_aec_dataType::aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_cct_data") == 0)
    {
        if (__index < mod_linearization33_cct_dataCount)
        {
            __result = mod_linearization33_cct_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_linearization33_aec_dataType::aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_cct_data") == 0)
    {
        if (__index < mod_linearization33_cct_dataCount)
        {
            __result = mod_linearization33_cct_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_linearization33_aec_dataType::aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_linearization33_cct_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_linearization33_cct_data", ParameterParserDataType::Structure, true, false, mod_linearization33_cct_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_linearization33_cct_data") == 0)
    {
        if (__index < mod_linearization33_cct_dataCount)
        {
            __result = mod_linearization33_cct_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_linearization33_cct_dataCount));
        }
    }

    return __result;
}

bool mod_linearization33_led_idx_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "led_idx_trigger") == 0)
    {
        ParameterUtils::DoubleToString((double)led_idx_trigger, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "led_idx_data") == 0)
    {
        __result = led_idx_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_linearization33_led_idx_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "led_idx_trigger") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            led_idx_trigger = (ispglobalelements::trigger_pt_type_led_idx)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "led_idx_data") == 0)
    {
        __result = led_idx_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_linearization33_led_idx_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // led_idx_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("led_idx_trigger", ParameterParserDataType::Int32, (double)led_idx_trigger, 0));
    }
    else if (PARAMETER_STRCMP(__name, "led_idx_trigger") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)led_idx_trigger, 0));
    }

    // led_idx_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("led_idx_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "led_idx_data") == 0)
    {
        __result = led_idx_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_linearization33_led_idx_dataType::led_idx_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_aec_data") == 0)
    {
        if (__index < mod_linearization33_aec_dataCount)
        {
            __result = mod_linearization33_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_linearization33_led_idx_dataType::led_idx_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_aec_data") == 0)
    {
        if (__index < mod_linearization33_aec_dataCount)
        {
            __result = mod_linearization33_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_linearization33_led_idx_dataType::led_idx_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_linearization33_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_linearization33_aec_data", ParameterParserDataType::Structure, true, false, mod_linearization33_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_linearization33_aec_data") == 0)
    {
        if (__index < mod_linearization33_aec_dataCount)
        {
            __result = mod_linearization33_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_linearization33_aec_dataCount));
        }
    }

    return __result;
}

bool mod_linearization33_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_linearization33_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_linearization33_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_linearization33_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_led_idx_data") == 0)
    {
        if (__index < mod_linearization33_led_idx_dataCount)
        {
            __result = mod_linearization33_led_idx_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_linearization33_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_led_idx_data") == 0)
    {
        if (__index < mod_linearization33_led_idx_dataCount)
        {
            __result = mod_linearization33_led_idx_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_linearization33_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_linearization33_led_idx_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_linearization33_led_idx_data", ParameterParserDataType::Structure, true, false, mod_linearization33_led_idx_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_linearization33_led_idx_data") == 0)
    {
        if (__index < mod_linearization33_led_idx_dataCount)
        {
            __result = mod_linearization33_led_idx_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_linearization33_led_idx_dataCount));
        }
    }

    return __result;
}

bool mod_linearization33_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_linearization33_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_linearization33_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_linearization33_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_hdr_aec_data") == 0)
    {
        if (__index < mod_linearization33_hdr_aec_dataCount)
        {
            __result = mod_linearization33_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_linearization33_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_hdr_aec_data") == 0)
    {
        if (__index < mod_linearization33_hdr_aec_dataCount)
        {
            __result = mod_linearization33_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_linearization33_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_linearization33_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_linearization33_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_linearization33_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_linearization33_hdr_aec_data") == 0)
    {
        if (__index < mod_linearization33_hdr_aec_dataCount)
        {
            __result = mod_linearization33_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_linearization33_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool chromatix_linearization33_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_drc_gain_data") == 0)
    {
        if (__index < mod_linearization33_drc_gain_dataCount)
        {
            __result = mod_linearization33_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_linearization33_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_linearization33_drc_gain_data") == 0)
    {
        if (__index < mod_linearization33_drc_gain_dataCount)
        {
            __result = mod_linearization33_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_linearization33_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_linearization33_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_linearization33_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_linearization33_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_linearization33_drc_gain_data") == 0)
    {
        if (__index < mod_linearization33_drc_gain_dataCount)
        {
            __result = mod_linearization33_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_linearization33_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_linearization33Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "private_information") == 0)
    {
        __result = private_information.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_linearization33_core") == 0)
    {
        __result = chromatix_linearization33_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_linearization33Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "private_information") == 0)
    {
        __result = private_information.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_linearization33_core") == 0)
    {
        __result = chromatix_linearization33_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_linearization33Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // private_information
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("private_information", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "private_information") == 0)
    {
        __result = private_information.GetInfo(&__path[__pos], __info);
    }

    // chromatix_linearization33_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_linearization33_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_linearization33_core") == 0)
    {
        __result = chromatix_linearization33_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_linearization33Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "linearization_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)linearization_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_linearization33Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "linearization_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            linearization_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_linearization33Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // linearization_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("linearization_enable", ParameterParserDataType::Int32, (double)linearization_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "linearization_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)linearization_enable, 0));
    }

    return __result;
}

bool chromatix_linearization33Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_linearization33Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_linearization33Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_linearization33Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_linearization33Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_linearization33Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_linearization33Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 5)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 5; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_linearization33Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 5)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 5)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_linearization33Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 5));
    }

    return __result;
}

bool chromatix_linearization33Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_linearization33Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_linearization33Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

bool chromatix_linearization33Type::private_informationStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "led_sensitivity_trigger") == 0)
    {
        __result = led_sensitivity_trigger.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_linearization33Type::private_informationStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "led_sensitivity_trigger") == 0)
    {
        __result = led_sensitivity_trigger.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_linearization33Type::private_informationStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // led_sensitivity_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("led_sensitivity_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "led_sensitivity_trigger") == 0)
    {
        __result = led_sensitivity_trigger.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_cct):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_cct;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_led_idx):
            enumValue = chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum::control_led_idx;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_linearization33Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_linearization33TypeClass::chromatix_linearization33TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(private_information);
    PARAMETER_INITIALIZE(chromatix_linearization33_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_linearization33TypeClass::chromatix_linearization33TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(private_information);
    PARAMETER_INITIALIZE(chromatix_linearization33_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_linearization33TypeClass::~chromatix_linearization33TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_linearization33TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "linearization33_ife")) == 0)
    {
        name = "linearization33_ife";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(r_lut_p_tab);
    PARAMETER_INITIALIZE(r_lut_base_tab);
    PARAMETER_INITIALIZE(gr_lut_p_tab);
    PARAMETER_INITIALIZE(gr_lut_base_tab);
    PARAMETER_INITIALIZE(gb_lut_p_tab);
    PARAMETER_INITIALIZE(gb_lut_base_tab);
    PARAMETER_INITIALIZE(b_lut_p_tab);
    PARAMETER_INITIALIZE(b_lut_base_tab);

    result = r_lut_p_tab.Load(entry, alignment);
    if (result)
    {
        result = r_lut_base_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = gr_lut_p_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = gr_lut_base_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = gb_lut_p_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = gb_lut_base_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = b_lut_p_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = b_lut_base_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_r_lut_p_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::r_lut_p_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(r_lut_p);

    result = entry->ReadArray(r_lut_p, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_r_lut_base_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::r_lut_base_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(r_lut_base);

    result = entry->ReadArray(r_lut_base, 9, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_gr_lut_p_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::gr_lut_p_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gr_lut_p);

    result = entry->ReadArray(gr_lut_p, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_gr_lut_base_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::gr_lut_base_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gr_lut_base);

    result = entry->ReadArray(gr_lut_base, 9, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_gb_lut_p_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::gb_lut_p_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gb_lut_p);

    result = entry->ReadArray(gb_lut_p, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_gb_lut_base_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::gb_lut_base_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gb_lut_base);

    result = entry->ReadArray(gb_lut_base, 9, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_b_lut_p_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::b_lut_p_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(b_lut_p);

    result = entry->ReadArray(b_lut_p, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load linearization33_rgn_dataType_b_lut_base_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool linearization33_rgn_dataType::b_lut_base_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(b_lut_base);

    result = entry->ReadArray(b_lut_base, 9, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_cct_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_cct_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(cct_trigger);
    PARAMETER_INITIALIZE(linearization33_rgn_data);

    result = cct_trigger.Load(entry, alignment);
    if (result)
    {
        result = linearization33_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(aec_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_aec_dataType_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_aec_dataType::aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_linearization33_cct_data);


    // Reading Array mod_linearization33_cct_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_linearization33_cct_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_linearization33_cct_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_linearization33_cct_dataID = pointerEntry->ID;
            DupObjInfo* mod_linearization33_cct_dataDupInfo = pointerEntry->GetDupObject(mod_linearization33_cct_dataCount, file, line);
            if (mod_linearization33_cct_dataDupInfo != nullptr && mod_linearization33_cct_dataDupInfo->Object != nullptr)
            {
                mod_linearization33_cct_data = (mod_linearization33_cct_dataType*)mod_linearization33_cct_dataDupInfo->Object;
                if (mod_linearization33_cct_data == nullptr)
                {
                    if (mod_linearization33_cct_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_cct_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_linearization33_cct_dataDupInfo->File, mod_linearization33_cct_dataDupInfo->Line, mod_linearization33_cct_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_cct_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_linearization33_cct_dataDupInfo->Line, mod_linearization33_cct_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_linearization33_cct_data == nullptr)
            {
                if (result && mod_linearization33_cct_dataCount > 0)
                {
                    mod_linearization33_cct_data = PARAMETER_NEW mod_linearization33_cct_dataType[mod_linearization33_cct_dataCount];
                    (void)pointerEntry->SetDupObject(mod_linearization33_cct_data, mod_linearization33_cct_dataCount, file, line);
                }
                if (!result || mod_linearization33_cct_data == nullptr)
                {
                    if (mod_linearization33_cct_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_linearization33_cct_data\n");
                    }
                    mod_linearization33_cct_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_linearization33_cct_dataCount; i++)
                {
                    result = mod_linearization33_cct_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_linearization33_cct_data == nullptr)
        {
            mod_linearization33_cct_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_led_idx_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_led_idx_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(led_idx_trigger);
    PARAMETER_INITIALIZE(led_idx_data);

    SYMBOL_TABLE_ENTRY_READ(entry, result, led_idx_trigger, alignment)
    if (result)
    {
        result = led_idx_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_led_idx_dataType_led_idx_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_led_idx_dataType::led_idx_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_linearization33_aec_data);


    // Reading Array mod_linearization33_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_linearization33_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_linearization33_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_linearization33_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_linearization33_aec_dataDupInfo = pointerEntry->GetDupObject(mod_linearization33_aec_dataCount, file, line);
            if (mod_linearization33_aec_dataDupInfo != nullptr && mod_linearization33_aec_dataDupInfo->Object != nullptr)
            {
                mod_linearization33_aec_data = (mod_linearization33_aec_dataType*)mod_linearization33_aec_dataDupInfo->Object;
                if (mod_linearization33_aec_data == nullptr)
                {
                    if (mod_linearization33_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_linearization33_aec_dataDupInfo->File, mod_linearization33_aec_dataDupInfo->Line, mod_linearization33_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_linearization33_aec_dataDupInfo->Line, mod_linearization33_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_linearization33_aec_data == nullptr)
            {
                if (result && mod_linearization33_aec_dataCount > 0)
                {
                    mod_linearization33_aec_data = PARAMETER_NEW mod_linearization33_aec_dataType[mod_linearization33_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_linearization33_aec_data, mod_linearization33_aec_dataCount, file, line);
                }
                if (!result || mod_linearization33_aec_data == nullptr)
                {
                    if (mod_linearization33_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_linearization33_aec_data\n");
                    }
                    mod_linearization33_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_linearization33_aec_dataCount; i++)
                {
                    result = mod_linearization33_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_linearization33_aec_data == nullptr)
        {
            mod_linearization33_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_linearization33_led_idx_data);


    // Reading Array mod_linearization33_led_idx_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_linearization33_led_idx_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_linearization33_led_idx_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_linearization33_led_idx_dataID = pointerEntry->ID;
            DupObjInfo* mod_linearization33_led_idx_dataDupInfo = pointerEntry->GetDupObject(mod_linearization33_led_idx_dataCount, file, line);
            if (mod_linearization33_led_idx_dataDupInfo != nullptr && mod_linearization33_led_idx_dataDupInfo->Object != nullptr)
            {
                mod_linearization33_led_idx_data = (mod_linearization33_led_idx_dataType*)mod_linearization33_led_idx_dataDupInfo->Object;
                if (mod_linearization33_led_idx_data == nullptr)
                {
                    if (mod_linearization33_led_idx_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_led_idx_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_linearization33_led_idx_dataDupInfo->File, mod_linearization33_led_idx_dataDupInfo->Line, mod_linearization33_led_idx_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_led_idx_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_linearization33_led_idx_dataDupInfo->Line, mod_linearization33_led_idx_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_linearization33_led_idx_data == nullptr)
            {
                if (result && mod_linearization33_led_idx_dataCount > 0)
                {
                    mod_linearization33_led_idx_data = PARAMETER_NEW mod_linearization33_led_idx_dataType[mod_linearization33_led_idx_dataCount];
                    (void)pointerEntry->SetDupObject(mod_linearization33_led_idx_data, mod_linearization33_led_idx_dataCount, file, line);
                }
                if (!result || mod_linearization33_led_idx_data == nullptr)
                {
                    if (mod_linearization33_led_idx_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_linearization33_led_idx_data\n");
                    }
                    mod_linearization33_led_idx_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_linearization33_led_idx_dataCount; i++)
                {
                    result = mod_linearization33_led_idx_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_linearization33_led_idx_data == nullptr)
        {
            mod_linearization33_led_idx_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_linearization33_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_linearization33_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_linearization33_hdr_aec_data);


    // Reading Array mod_linearization33_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_linearization33_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_linearization33_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_linearization33_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_linearization33_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_linearization33_hdr_aec_dataCount, file, line);
            if (mod_linearization33_hdr_aec_dataDupInfo != nullptr && mod_linearization33_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_linearization33_hdr_aec_data = (mod_linearization33_hdr_aec_dataType*)mod_linearization33_hdr_aec_dataDupInfo->Object;
                if (mod_linearization33_hdr_aec_data == nullptr)
                {
                    if (mod_linearization33_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_linearization33_hdr_aec_dataDupInfo->File, mod_linearization33_hdr_aec_dataDupInfo->Line, mod_linearization33_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_linearization33_hdr_aec_dataDupInfo->Line, mod_linearization33_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_linearization33_hdr_aec_data == nullptr)
            {
                if (result && mod_linearization33_hdr_aec_dataCount > 0)
                {
                    mod_linearization33_hdr_aec_data = PARAMETER_NEW mod_linearization33_hdr_aec_dataType[mod_linearization33_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_linearization33_hdr_aec_data, mod_linearization33_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_linearization33_hdr_aec_data == nullptr)
                {
                    if (mod_linearization33_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_linearization33_hdr_aec_data\n");
                    }
                    mod_linearization33_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_linearization33_hdr_aec_dataCount; i++)
                {
                    result = mod_linearization33_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_linearization33_hdr_aec_data == nullptr)
        {
            mod_linearization33_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_linearization33_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_linearization33_drc_gain_data);


    // Reading Array mod_linearization33_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_linearization33_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_linearization33_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_linearization33_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_linearization33_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_linearization33_drc_gain_dataCount, file, line);
            if (mod_linearization33_drc_gain_dataDupInfo != nullptr && mod_linearization33_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_linearization33_drc_gain_data = (mod_linearization33_drc_gain_dataType*)mod_linearization33_drc_gain_dataDupInfo->Object;
                if (mod_linearization33_drc_gain_data == nullptr)
                {
                    if (mod_linearization33_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_linearization33_drc_gain_dataDupInfo->File, mod_linearization33_drc_gain_dataDupInfo->Line, mod_linearization33_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_linearization33_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_linearization33_drc_gain_dataDupInfo->Line, mod_linearization33_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_linearization33_drc_gain_data == nullptr)
            {
                if (result && mod_linearization33_drc_gain_dataCount > 0)
                {
                    mod_linearization33_drc_gain_data = PARAMETER_NEW mod_linearization33_drc_gain_dataType[mod_linearization33_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_linearization33_drc_gain_data, mod_linearization33_drc_gain_dataCount, file, line);
                }
                if (!result || mod_linearization33_drc_gain_data == nullptr)
                {
                    if (mod_linearization33_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_linearization33_drc_gain_data\n");
                    }
                    mod_linearization33_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_linearization33_drc_gain_dataCount; i++)
                {
                    result = mod_linearization33_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_linearization33_drc_gain_data == nullptr)
        {
            mod_linearization33_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_linearization33Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(private_information);
    PARAMETER_INITIALIZE(chromatix_linearization33_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = private_information.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_linearization33_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(linearization_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, linearization_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 5; i++)
    {
        result = chromatix_linearization33Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load private_informationStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33Type::private_informationStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(led_sensitivity_trigger);

    result = led_sensitivity_trigger.Load(entry, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_aec_dataType_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_aec_dataType::aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_linearization33_cct_data))
    {
        PARAMETER_DELETE[] mod_linearization33_cct_data;
    }
    mod_linearization33_cct_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_led_idx_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_led_idx_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    led_idx_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_led_idx_dataType_led_idx_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_led_idx_dataType::led_idx_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_linearization33_aec_dataCount; i++)
    {
        mod_linearization33_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_linearization33_aec_data))
    {
        PARAMETER_DELETE[] mod_linearization33_aec_data;
    }
    mod_linearization33_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_linearization33_led_idx_dataCount; i++)
    {
        mod_linearization33_led_idx_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_linearization33_led_idx_data))
    {
        PARAMETER_DELETE[] mod_linearization33_led_idx_data;
    }
    mod_linearization33_led_idx_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_linearization33_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_linearization33_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_linearization33_hdr_aec_dataCount; i++)
    {
        mod_linearization33_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_linearization33_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_linearization33_hdr_aec_data;
    }
    mod_linearization33_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_linearization33_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_linearization33_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_linearization33_drc_gain_dataCount; i++)
    {
        mod_linearization33_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_linearization33_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_linearization33_drc_gain_data;
    }
    mod_linearization33_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_linearization33Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_linearization33Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_linearization33_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_linearization33Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_linearization33Type::Release()
{
    ((chromatix_linearization33TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_linearization33Type::GetModified()
{
    return ((chromatix_linearization33TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_linearization33TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_linearization33TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_linearization33TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_linearization33TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_linearization33TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_linearization33TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_linearization33TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_linearization33TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_linearization33TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_linearization33TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_linearization33TypeClass::Release()
{
    ParameterModule::Release();
}

LINEARIZATION_3_3_0_NAMESPACE_END
